import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import com.jinsight.jetchart.*;

/**
 * This application demonstrates how to set an image as the chart background.
 * An image  can  be positioned  at the  top left corner, at the  center  of
 * the background area or tiled. The background image area can be the parent
 * container  area  or just  the  graph  area, delimited  by  the horizontal 
 * and vertical axis coordinates.
 *
 * @author Andre de Lima Soares - alsoares@jinsight.com
 */
public class Main extends JFrame implements ItemListener {

    Graph graph;
    JPanel topPanel;
    JComboBox images,imagePosition,imageArea;
    Image rainImage,paperImage,marbleImage,woodImage,iceImage;
    LineSerie ls;
    

    public Main() {

	setTitle("The JetChart Library - Background Image Demo");

        addWindowListener(new WindowAdapter() {
           public void windowClosing(WindowEvent evt) {
              System.exit(0);
           }
        });
                             
	createTopPanel();

	createSeries();

	graph=new Graph();

	graph.setTitle(new String[]{"The JetChart Library","Background Image Demo"});
	graph.setStartDate("07012001");
	graph.setMonthLabelsEnabled(true);
	
	// Gets the primary GraphSet and sets scale position and enables grid.
	GraphSet graphSet=graph.getGraphSet(0);

	Scale scale=graphSet.getScale();
	scale.setPosition(Scale.LEFT_RIGHT);
	
	Grid grid=graphSet.getGrid();
	grid.setEnabled(true);

	graph.addSerie(ls);

	// Loads images.
	getImages();

	// Tiles the Image object across the chart area.
	graph.setBackgroundImage(rainImage,Graph.TILE);

        Container ct=getContentPane();
	ct.add("North",topPanel);
	ct.add("Center",graph);

	setSize(600,400);
	setVisible(true);

    }

    private void createTopPanel() {

        Font font=new Font("SansSerif",Font.PLAIN,10);
        String[] s={"Rain","Paper","Marble","Wood","Ice"};
        images=new JComboBox(s);
        images.setFont(font);
        images.addItemListener(this);

        s=new String[]{"Tile","Top left","Center"};
        imagePosition=new JComboBox(s);
        imagePosition.setFont(font);
        imagePosition.addItemListener(this);
       
	topPanel=new JPanel(new FlowLayout(FlowLayout.LEFT));
        JLabel label=new JLabel("Background pattern:");
        label.setFont(font);
	topPanel.add(label);
	topPanel.add(images);
	
        label=new JLabel("Image position:");
        label.setFont(font);
	topPanel.add(label);
	topPanel.add(imagePosition);

        s=new String[]{"Window Area","Graph Area"};
        imageArea=new JComboBox(s);
        imageArea.setFont(font);
        imageArea.addItemListener(this);

        label=new JLabel("Image area:");
        label.setFont(font);
        topPanel.add(label);
	topPanel.add(imageArea);

    }

    private void createSeries() {
	double[] values={131.90,132.80,130.50,131.00,136.75,135.00,131.50,130.50,
			 132.40,133.30,130.90,123.40,122.25,118.00,120.00,116.10,
			 115.00,103.45,107.50,103.80,99.00,96.75,94.00,95.90,97.50,
			 98.40,100.20,102.00,110.40,104.50,108.70,107.75,107.45,
			 103.00,100.90,99.25,93.80,99.25,103.00,100.25,102.70,
			 107.15,106.00,107.15,109.00,104.00,96.50,97.95,99.70,
			 97.70,91.00,87.45,86.80,88.60,85.40,85.90,84.85,
			 76.55, 68.00,67.45,61.90,60.90,60.75,53.60,58.50,
			 57.20,51.25,48.50,45.75,46.90,52.55,51.40,54.00,
			 51.70,41.20,38.75,34.00,33.50,33.25,34.25,33.90,
			 30.00,33.50,34.95,31.45,26.95,28.40,30.90,28.90,
			 29.90,29.80,33.25,34.50,34.00,36.90,37.00,36.40,
			 34.70,37.50,38.30,39.40,43.50,45.80,48.70,46.45,
			 47.85,49.40,54.90,55.50,56.95,58.75,61.80,58.50,
			 59.90,61.20,65.50,67.50,66.75,65.45,66.50,68.10,
			 64.80,57.70,59.80,57.80,57.00,55.25,61.30,66.90,
			 66.00,61.00,57.90,59.50,55.90,55.75,56.00,59.40,
			 58.85,55.40,50.05,49.50,49.80,59.00,57.40,60.00,
			 68.50,73.60,77.50,80.90,79.90};
	

        ls=new LineSerie(values,"Line series");
	ls.setColor(Color.green.darker());
	ls.setThickness(2);
	ls.setMarksEnabled(false);

    }

    private void getImages() {
	
	/**
	 * The SVGImageFactory is an image filter that creates a new Image object from an image source, but 
	 * including the URL where it is found as a property. During an SVG encoding process, the SVGGraphics
	 * class, created and invoked from within the ChartEncoder instance, checks if the Image object
	 * has a xlink:href attribute and if affirmative the <image> tag points to the image URL, otherwise,
	 * the image bytes are converted into a base64 sequence of characters and embedded into the SVG
	 * code. In the specific case of images tiled on the background, the SVG encoding process may take
	 * a long time if the images are not recreated with the SVGImageFactory class to include
	 * a xlink:href attribute, because the original image is replicated to fill the background and each
	 * of the tiled images are converted into a base64 encoded sequence of characters if no xlink:href
	 * attribute is found. 
	 * If no SVG encoding will take place, there is no need to use the SVGImageFactory class. 
	 */
	rainImage=Toolkit.getDefaultToolkit().getImage("rain.jpg");

	paperImage=Toolkit.getDefaultToolkit().getImage("paper.jpg");

	marbleImage=Toolkit.getDefaultToolkit().getImage("marble.jpg");

	woodImage=Toolkit.getDefaultToolkit().getImage("wood.jpg");

	iceImage=Toolkit.getDefaultToolkit().getImage("ice.jpg");

    }	    

    public void itemStateChanged(ItemEvent evt) {

	int index=images.getSelectedIndex();
	int position=imagePosition.getSelectedIndex();
	int area=imageArea.getSelectedIndex();

	switch (index) {
	case 0: {
	    graph.setBackgroundImage(rainImage,position);
	    break;
	}
	case 1: {
	    graph.setBackgroundImage(paperImage,position);
	    break;
	}
	case 2: {
	    graph.setBackgroundImage(marbleImage,position);
	    break;
	}
	case 3: {
	    graph.setBackgroundImage(woodImage,position);
	    break;
	}
	case 4: {
	    graph.setBackgroundImage(iceImage,position);
	}
	}

	// The background image area can be the container's area
	// or just  the  area  delimited  by  the horizontal and
	// vertical axis coordinates.
	graph.setBackgroundImageArea(area);

	graph.repaint();


    }
    
    public static void main(String[] args) {
	new Main();
    }
}
