import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import com.jinsight.jetchart.*;
import java.util.Vector;

/**
 * This class displays a dialog box with options to set pie chart properties.
 *
 * @author Andre de Lima Soares - alsoares@jinsight.com
 */
public class PieConsole extends JDialog implements AdjustmentListener,ItemListener {
    JScrollBar xRadiusInsets,yRadiusInsets,depth,legendDistance;
    Main pChart;
    JCheckBox circled,border,legend,position,is3D,tooltip,title,xTitle,yTitle,graphLegend;
    JComboBox content,borderType;

    public PieConsole(JFrame frame,boolean isModal) {

        super(frame,isModal);

	setTitle("Control Panel");

	GridBagLayout gb=new GridBagLayout();
	GridBagConstraints gc=new GridBagConstraints();
	
        Container ct=getContentPane();

        ct.setLayout(gb);

	createComponents(ct,gb,gc);

	addWindowListener(new WindowAdapter() {
	    public void windowClosing(WindowEvent evt) {
		setVisible(false);
	    }
	});

        setSize(400,300);

	setVisible(true);
    }

    public void setGraph(Main pChart) {
       this.pChart=pChart;
    }

    private void createComponents(Container ct,GridBagLayout gb,GridBagConstraints gc) {
	gc.fill=GridBagConstraints.BOTH;
	gc.weightx=1.0;
	gc.anchor=GridBagConstraints.WEST;
	gc.insets=new Insets(2,2,2,2);

	// creates labels for scrollbars
	JLabel labelXRadiusInsets=new JLabel("Horizontal insets",Label.LEFT);
	setCompFont(labelXRadiusInsets);
	JLabel labelYRadiusInsets=new JLabel("Vertical insets",Label.LEFT);
	setCompFont(labelYRadiusInsets);
	gb.setConstraints(labelXRadiusInsets,gc);
	ct.add(labelXRadiusInsets);
	
	gc.gridwidth=GridBagConstraints.REMAINDER;
	gb.setConstraints(labelYRadiusInsets,gc);
	ct.add(labelYRadiusInsets);

	gc.gridwidth=1;

	// creates scrollbars for xRadiusInsets and yRadiusInsets adjustment
	xRadiusInsets=new JScrollBar(Scrollbar.HORIZONTAL,0,1,0,50);
	xRadiusInsets.addAdjustmentListener(this);
	yRadiusInsets=new JScrollBar(Scrollbar.HORIZONTAL,0,1,0,50);
	yRadiusInsets.addAdjustmentListener(this);

	gb.setConstraints(xRadiusInsets,gc);
	ct.add(xRadiusInsets);

	gc.gridwidth=GridBagConstraints.REMAINDER;
	gb.setConstraints(yRadiusInsets,gc);
	ct.add(yRadiusInsets);

	gc.gridwidth=1;
	gc.fill=GridBagConstraints.NONE;
	circled=new JCheckBox("Circled pie");
	setCompFont(circled);
	circled.addItemListener(this);
	gb.setConstraints(circled,gc);
	ct.add(circled);

	gc.gridwidth=GridBagConstraints.REMAINDER;
	border=new JCheckBox("Show borders");
	setCompFont(border);
	border.addItemListener(this);
	gb.setConstraints(border,gc);
	ct.add(border);

	gc.gridwidth=1;
	legend=new JCheckBox("Show slice legends");
	setCompFont(legend);
	legend.addItemListener(this);
	gb.setConstraints(legend,gc);
	ct.add(legend);
	
	gc.gridwidth=GridBagConstraints.REMAINDER;
	position=new JCheckBox("Move slice legends outside");
	setCompFont(position);
	position.setEnabled(false);
	position.addItemListener(this);
	gb.setConstraints(position,gc);
	ct.add(position);

	gc.gridwidth=1;
	is3D=new JCheckBox("3D");
	setCompFont(is3D);
	is3D.setSelected(true);
	is3D.addItemListener(this);
	gb.setConstraints(is3D,gc);
	ct.add(is3D);

	gc.gridwidth=GridBagConstraints.REMAINDER;
	tooltip=new JCheckBox("Enable tooltip");
	setCompFont(tooltip);
	tooltip.addItemListener(this);
	gb.setConstraints(tooltip,gc);
	ct.add(tooltip);

	gc.gridwidth=1;
	title=new JCheckBox("Show chart title");
	setCompFont(title);
	title.addItemListener(this);
	gb.setConstraints(title,gc);
	ct.add(title);

	gc.gridwidth=GridBagConstraints.REMAINDER;
	xTitle=new JCheckBox("Show bottom title");
	setCompFont(xTitle);
	xTitle.addItemListener(this);
	gb.setConstraints(xTitle,gc);
	ct.add(xTitle);

	gc.gridwidth=1;
	yTitle=new JCheckBox("Show left title");
	setCompFont(yTitle);
	yTitle.addItemListener(this);
	gb.setConstraints(yTitle,gc);
	ct.add(yTitle);

	gc.gridwidth=GridBagConstraints.REMAINDER;
	graphLegend=new JCheckBox("Show graph legend");
	setCompFont(graphLegend);
	graphLegend.setSelected(true);
	graphLegend.addItemListener(this);
	gb.setConstraints(graphLegend,gc);
	ct.add(graphLegend);
	
	gc.gridwidth=1;
	gc.fill=GridBagConstraints.BOTH;
	gc.insets=new Insets(0,0,0,0);
	JLabel labelContent=new JLabel("Legend content",Label.LEFT);
	JLabel labelBorderType=new JLabel("Legend border type",Label.LEFT);

	setCompFont(labelContent);
	setCompFont(labelBorderType);
	
	gb.setConstraints(labelContent,gc);
	ct.add(labelContent);

	gc.gridwidth=GridBagConstraints.REMAINDER;
	gb.setConstraints(labelBorderType,gc);
	ct.add(labelBorderType);
	
	gc.gridwidth=1;

        String[] items={"VALUE","PERCENT","LABEL","LABEL AND VALUE","LABEL AND PERCENT",
                        "VALUE AND PERCENT"};
        content=new JComboBox(items);
	content.setEnabled(false);
	content.addItemListener(this);
	gb.setConstraints(content,gc);
	ct.add(content);
	
	gc.gridwidth=GridBagConstraints.REMAINDER;
        items=new String[]{"SHADOWED","LOWERED BEVEL","RAISED BEVEL"};
	borderType=new JComboBox(items);
	borderType.setEnabled(false);
	borderType.addItemListener(this);
	gb.setConstraints(borderType,gc);
	ct.add(borderType);

	gc.gridwidth=1;

	JLabel labelLegendDistance=new JLabel("Legend vertex distance",Label.LEFT);
	setCompFont(labelLegendDistance);
	gb.setConstraints(labelLegendDistance,gc);
	ct.add(labelLegendDistance);

	gc.gridwidth=GridBagConstraints.REMAINDER;

	JLabel labelDepth=new JLabel("3D depth",Label.LEFT);
	setCompFont(labelDepth);
	gb.setConstraints(labelDepth,gc);
	ct.add(labelDepth);

	gc.gridwidth=1;
	legendDistance=new JScrollBar(JScrollBar.HORIZONTAL,7,1,0,10);
	legendDistance.setEnabled(false);
	legendDistance.addAdjustmentListener(this);
	gb.setConstraints(legendDistance,gc);
	ct.add(legendDistance);


	gc.gridwidth=GridBagConstraints.REMAINDER;
	
	depth=new JScrollBar(JScrollBar.HORIZONTAL,10,1,0,50);
	gb.setConstraints(depth,gc);
	ct.add(depth);
	depth.addAdjustmentListener(this);
	

    }

    public void adjustmentValueChanged(AdjustmentEvent evt) {
	if (evt.getSource()==xRadiusInsets)
	    pChart.ps.setXRadiusInset(xRadiusInsets.getValue());
	else if (evt.getSource()==yRadiusInsets)
	    pChart.ps.setYRadiusInset(yRadiusInsets.getValue());
	else if (evt.getSource()==depth)
	    pChart.ps.set3DDepth(depth.getValue());
	else if (evt.getSource()==legendDistance) {
	    Vector slices=pChart.ps.getSlices();
	    for (int counter=0;counter<slices.size();counter++) {
		Slice slice=(Slice)slices.elementAt(counter);
		slice.getSliceLegend().setVertexDistance(((double)legendDistance.getValue())/10);
	    }
	}
	    
	pChart.graph.repaint();
	
    }

    public void itemStateChanged(ItemEvent evt) {
	if (evt.getSource()==circled) 
	    pChart.ps.setCircledEnabled(circled.isSelected());

	else if (evt.getSource()==border)
	    pChart.ps.setBorderEnabled(border.isSelected());

	else if (evt.getSource()==legend) {
	    
	    Vector slices=pChart.ps.getSlices();
	    for (int counter=0;counter<slices.size();counter++) {
		Slice slice=(Slice)slices.elementAt(counter);
		slice.getSliceLegend().setEnabled(legend.isSelected());
	    }

	    legendDistance.setEnabled(legend.isSelected());
	    position.setEnabled(legend.isSelected());
	    content.setEnabled(legend.isSelected());
	    borderType.setEnabled(legend.isSelected());
	}

	else if (evt.getSource()==position) {
	    Vector slices=pChart.ps.getSlices();
	    for (int counter=0;counter<slices.size();counter++) {
		Slice slice=(Slice)slices.elementAt(counter);
		slice.getSliceLegend().setPosition(position.isSelected() ? SliceLegend.OUTSIDE : SliceLegend.INSIDE);
	    }
	}

	else if (evt.getSource()==content) {
	    Vector slices=pChart.ps.getSlices();
	    for (int counter=0;counter<slices.size();counter++) {
		Slice slice=(Slice)slices.elementAt(counter);
		slice.getSliceLegend().setContent(content.getSelectedIndex());
	    }
	}

	else if (evt.getSource()==borderType) {
	    Vector slices=pChart.ps.getSlices();
	    for (int counter=0;counter<slices.size();counter++) {
		Slice slice=(Slice)slices.elementAt(counter);
		slice.getSliceLegend().setBorder(borderType.getSelectedIndex());
	    }
	}

	else if (evt.getSource()==is3D)
	    pChart.graph.set3DEnabled(is3D.isSelected());

	else if (evt.getSource()==tooltip)
	    pChart.graph.getToolTip().setEnabled(tooltip.isSelected());

	else if (evt.getSource()==title) {
	    if (title.isSelected())
		pChart.graph.setTitle(new String[]{"PIE CHART TITLE"});
	    else
		pChart.graph.setTitle(null);
	}

	else if (evt.getSource()==xTitle) {
	    if (xTitle.isSelected())
		pChart.graph.getBottomTitle().setText("BOTTOM TITLE");
	    else
		pChart.graph.getBottomTitle().setText(null);
	}

	else if (evt.getSource()==yTitle) {
	    if (yTitle.isSelected())
		pChart.graph.getLeftTitle().setText("LEFT TITLE");
	    else
		pChart.graph.getLeftTitle().setText(null);
	}

	else if (evt.getSource()==graphLegend) 
	    pChart.graph.setLegendEnabled(graphLegend.isSelected());

	pChart.graph.repaint();

    }
    

    private void setCompFont(Component c) {
	c.setFont(new Font("Arial",Font.PLAIN,10));
    }
	
}

